==> 0.0.68.tar.gz: lib/src/custom_components/custom_radio/view_model.dart <==


import 'package:flutter/material.dart';
import 'view.dart';

class OwlnextRadio extends StatefulWidget {
  /// Owlnext form input
  /// Based on Material design and uses [FormField]
  /// Used to automate all radio behaviors ine one place
  /// 
  /// Create a custom [FormField] in order to have form validation
  /// Refers to the props to see how to use
  const OwlnextRadio({
    super.key,
    required this.options,
    required this.selectedOption,
    required this.handleChangeSelected,
    required this.label,
    this.infoCallback,
    this.isMandatory = false,
    this.enabled = true,
    this.disabledMessage
  });

  /// Options list to display and select from
  final List<CustomRadioOption> options;
  /// Current selected value
  final String? selectedOption;
  /// Callback on option click
  /// Return the clicked option
  final void Function(CustomRadioOption) handleChangeSelected;
  /// Radio label
  final String label;
  /// Callback triggered when the '?' right of the label
  /// Doesn't display if null
  final Function? infoCallback;
  /// Determines the validator behavior
  final bool isMandatory;
  /// Determines if the radio is enabled
  final bool enabled;
  /// Message to show if the radio is disabled
  final String? disabledMessage;

  @override
  OwlnextRadioState createState() {
    return OwlnextRadioState();
  }
}

class OwlnextRadioState extends State<OwlnextRadio> with ViewMixin {
  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }
  
  @override
  Widget build(BuildContext context) {
    return render(context, this);
  }
}

class CustomRadioOption {
  Widget widget;
  String value;

  CustomRadioOption({
    required this.widget,
    required this.value,
  });
}

==> 0.0.82.tar.gz: lib/src/custom_components/custom_radio/view_model.dart <==


import 'package:flutter/material.dart';
import 'view.dart';

class OwlnextRadio extends StatefulWidget {
  /// Owlnext form input
  /// Based on Material design and uses [FormField]
  /// Used to automate all radio behaviors ine one place
  /// 
  /// Create a custom [FormField] in order to have form validation
  /// Refers to the props to see how to use
  const OwlnextRadio({
    super.key,
    required this.options,
    required this.selectedOption,
    required this.handleChangeSelected,
    required this.label,
    this.infoCallback,
    this.isMandatory = false,
    this.enabled = true,
    this.disabledMessage,
    this.axis = Axis.vertical,
  });

  /// Options list to display and select from
  final List<CustomRadioOption> options;
  /// Current selected value
  final String? selectedOption;
  /// Callback on option click
  /// Return the clicked option
  final void Function(CustomRadioOption) handleChangeSelected;
  /// Radio label
  final String label;
  /// Callback triggered when the '?' right of the label
  /// Doesn't display if null
  final Function? infoCallback;
  /// Determines the validator behavior
  final bool isMandatory;
  /// Determines if the radio is enabled
  final bool enabled;
  /// Message to show if the radio is disabled
  final String? disabledMessage;
  /// Set the axis for the label -> input
  final Axis? axis;

  @override
  OwlnextRadioState createState() {
    return OwlnextRadioState();
  }
}

class OwlnextRadioState extends State<OwlnextRadio> with ViewMixin {
  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }
  
  @override
  Widget build(BuildContext context) {
    return render(context, this);
  }
}

class CustomRadioOption {
  Widget widget;
  String value;

  CustomRadioOption({
    required this.widget,
    required this.value,
  });
}
